Vector of SQLite Keywords.
sqlite_keywords.RdA character vector containing the current SQLite Keywords. These strings can not be used as variable names in eatDB.
sqlite_keywords.RdA character vector containing the current SQLite Keywords. These strings can not be used as variable names in eatDB.